==> webpdf-wsclient-1.0.1-sources.jar: net/webpdf/wsclient/schema/operation/ConverterMailType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ConverterMailType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ConverterMailType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;attribute name="downloadImages" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="adjustFonts" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="attachmentMode" type="{http://schema.webpdf.de/1.0/operation}AttachmentModeType" default="embed" /&gt;
 *       &lt;attribute name="ignoreMissingBodyChunk" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ConverterMailType")
public class ConverterMailType {

    @XmlAttribute(name = "downloadImages")
    protected Boolean downloadImages;
    @XmlAttribute(name = "adjustFonts")
    protected Boolean adjustFonts;
    @XmlAttribute(name = "attachmentMode")
    protected AttachmentModeType attachmentMode;
    @XmlAttribute(name = "ignoreMissingBodyChunk")
    protected Boolean ignoreMissingBodyChunk;

    /**
     * Gets the value of the downloadImages property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isDownloadImages() {
        if (downloadImages == null) {
            return false;
        } else {
            return downloadImages;
        }
    }

    /**
     * Sets the value of the downloadImages property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setDownloadImages(boolean value) {
        this.downloadImages = value;
    }

    public boolean isSetDownloadImages() {
        return (this.downloadImages!= null);
    }

    public void unsetDownloadImages() {
        this.downloadImages = null;
    }

    /**
     * Gets the value of the adjustFonts property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isAdjustFonts() {
        if (adjustFonts == null) {
            return false;
        } else {
            return adjustFonts;
        }
    }

    /**
     * Sets the value of the adjustFonts property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setAdjustFonts(boolean value) {
        this.adjustFonts = value;
    }

    public boolean isSetAdjustFonts() {
        return (this.adjustFonts!= null);
    }

    public void unsetAdjustFonts() {
        this.adjustFonts = null;
    }

    /**
     * Gets the value of the attachmentMode property.
     * 
     * @return
     *     possible object is
     *     {@link AttachmentModeType }
     *     
     */
    public AttachmentModeType getAttachmentMode() {
        if (attachmentMode == null) {
            return AttachmentModeType.EMBED;
        } else {
            return attachmentMode;
        }
    }

    /**
     * Sets the value of the attachmentMode property.
     * 
     * @param value
     *     allowed object is
     *     {@link AttachmentModeType }
     *     
     */
    public void setAttachmentMode(AttachmentModeType value) {
        this.attachmentMode = value;
    }

    public boolean isSetAttachmentMode() {
        return (this.attachmentMode!= null);
    }

    /**
     * Gets the value of the ignoreMissingBodyChunk property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isIgnoreMissingBodyChunk() {
        if (ignoreMissingBodyChunk == null) {
            return false;
        } else {
            return ignoreMissingBodyChunk;
        }
    }

    /**
     * Sets the value of the ignoreMissingBodyChunk property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIgnoreMissingBodyChunk(boolean value) {
        this.ignoreMissingBodyChunk = value;
    }

    public boolean isSetIgnoreMissingBodyChunk() {
        return (this.ignoreMissingBodyChunk!= null);
    }

    public void unsetIgnoreMissingBodyChunk() {
        this.ignoreMissingBodyChunk = null;
    }

}

==> webpdf-wsclient-2.0.0-sources.jar: net/webpdf/wsclient/schema/operation/ConverterMailType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ConverterMailType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ConverterMailType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;attribute name="downloadImages" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="adjustFonts" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="attachmentMode" type="{http://schema.webpdf.de/1.0/operation}AttachmentModeType" default="embed" /&gt;
 *       &lt;attribute name="ignoreMissingBodyChunk" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="useBackground" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ConverterMailType")
public class ConverterMailType {

    @XmlAttribute(name = "downloadImages")
    protected Boolean downloadImages;
    @XmlAttribute(name = "adjustFonts")
    protected Boolean adjustFonts;
    @XmlAttribute(name = "attachmentMode")
    protected AttachmentModeType attachmentMode;
    @XmlAttribute(name = "ignoreMissingBodyChunk")
    protected Boolean ignoreMissingBodyChunk;
    @XmlAttribute(name = "useBackground")
    protected Boolean useBackground;

    /**
     * Gets the value of the downloadImages property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isDownloadImages() {
        if (downloadImages == null) {
            return false;
        } else {
            return downloadImages;
        }
    }

    /**
     * Sets the value of the downloadImages property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setDownloadImages(boolean value) {
        this.downloadImages = value;
    }

    public boolean isSetDownloadImages() {
        return (this.downloadImages!= null);
    }

    public void unsetDownloadImages() {
        this.downloadImages = null;
    }

    /**
     * Gets the value of the adjustFonts property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isAdjustFonts() {
        if (adjustFonts == null) {
            return false;
        } else {
            return adjustFonts;
        }
    }

    /**
     * Sets the value of the adjustFonts property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setAdjustFonts(boolean value) {
        this.adjustFonts = value;
    }

    public boolean isSetAdjustFonts() {
        return (this.adjustFonts!= null);
    }

    public void unsetAdjustFonts() {
        this.adjustFonts = null;
    }

    /**
     * Gets the value of the attachmentMode property.
     * 
     * @return
     *     possible object is
     *     {@link AttachmentModeType }
     *     
     */
    public AttachmentModeType getAttachmentMode() {
        if (attachmentMode == null) {
            return AttachmentModeType.EMBED;
        } else {
            return attachmentMode;
        }
    }

    /**
     * Sets the value of the attachmentMode property.
     * 
     * @param value
     *     allowed object is
     *     {@link AttachmentModeType }
     *     
     */
    public void setAttachmentMode(AttachmentModeType value) {
        this.attachmentMode = value;
    }

    public boolean isSetAttachmentMode() {
        return (this.attachmentMode!= null);
    }

    /**
     * Gets the value of the ignoreMissingBodyChunk property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isIgnoreMissingBodyChunk() {
        if (ignoreMissingBodyChunk == null) {
            return false;
        } else {
            return ignoreMissingBodyChunk;
        }
    }

    /**
     * Sets the value of the ignoreMissingBodyChunk property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIgnoreMissingBodyChunk(boolean value) {
        this.ignoreMissingBodyChunk = value;
    }

    public boolean isSetIgnoreMissingBodyChunk() {
        return (this.ignoreMissingBodyChunk!= null);
    }

    public void unsetIgnoreMissingBodyChunk() {
        this.ignoreMissingBodyChunk = null;
    }

    /**
     * Gets the value of the useBackground property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isUseBackground() {
        if (useBackground == null) {
            return true;
        } else {
            return useBackground;
        }
    }

    /**
     * Sets the value of the useBackground property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setUseBackground(boolean value) {
        this.useBackground = value;
    }

    public boolean isSetUseBackground() {
        return (this.useBackground!= null);
    }

    public void unsetUseBackground() {
        this.useBackground = null;
    }

}
